Sign in to {{ project_name }}
Copy and paste this link into your browser to sign in:
{{ login_url }}
This link will expire in 15 minutes.
If you didn't request this, you can safely ignore this email.
